# stauth

Streamlit authentication components
  
## Installation

```python
pip install stauth
```

## Example

Clone the repo and launch the example Streamlit page:
```console
poetry run streamlit run example.py
```
